@@ -698,7 +698,7 @@ out_abort:
 #if LINUX_VERSION_CODE < KERNEL_VERSION(5, 12, 0)
 int apfs_mknod(struct inode *dir, struct dentry *dentry, umode_t mode,
 	       dev_t rdev)
-#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0) && !RHEL_VERSION_GE(9, 6)
 int apfs_mknod(struct user_namespace *mnt_userns, struct inode *dir,
 	       struct dentry *dentry, umode_t mode, dev_t rdev)
 #else
@@ -716,7 +716,7 @@ int apfs_mkdir(struct inode *dir, struct dentry *dentry, umode_t mode)
 	return apfs_mknod(dir, dentry, mode | S_IFDIR, 0 /* rdev */);
 }
 
-#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0) && !RHEL_VERSION_GE(9, 6)
 
 int apfs_mkdir(struct user_namespace *mnt_userns, struct inode *dir,
 	       struct dentry *dentry, umode_t mode)
@@ -724,7 +724,7 @@ int apfs_mkdir(struct user_namespace *mnt_userns, struct inode *dir,
 	return apfs_mknod(mnt_userns, dir, dentry, mode | S_IFDIR, 0 /* rdev */);
 }
 
-#else
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 15, 0)
 
 int apfs_mkdir(struct mnt_idmap *idmap, struct inode *dir,
 	       struct dentry *dentry, umode_t mode)
@@ -732,6 +732,13 @@ int apfs_mkdir(struct mnt_idmap *idmap, struct inode *dir,
 	return apfs_mknod(idmap, dir, dentry, mode | S_IFDIR, 0 /* rdev */);
 }
 
+#else
+
+struct dentry *apfs_mkdir(struct mnt_idmap *idmap, struct inode *dir, struct dentry *dentry, umode_t mode)
+{
+	return ERR_PTR(apfs_mknod(idmap, dir, dentry, mode | S_IFDIR, 0 /* rdev */));
+}
+
 #endif
 
 
@@ -743,7 +750,7 @@ int apfs_create(struct inode *dir, struct dentry *dentry, umode_t mode,
 	return apfs_mknod(dir, dentry, mode, 0 /* rdev */);
 }
 
-#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0) && !RHEL_VERSION_GE(9, 6)
 
 int apfs_create(struct user_namespace *mnt_userns, struct inode *dir,
 		struct dentry *dentry, umode_t mode, bool excl)
@@ -1373,7 +1380,7 @@ int apfs_rmdir(struct inode *dir, struct dentry *dentry)
 int apfs_rename(struct inode *old_dir, struct dentry *old_dentry,
 		struct inode *new_dir, struct dentry *new_dentry,
 		unsigned int flags)
-#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0)
+#elif LINUX_VERSION_CODE < KERNEL_VERSION(6, 3, 0) && !RHEL_VERSION_GE(9, 6)
 int apfs_rename(struct user_namespace *mnt_userns, struct inode *old_dir,
 		struct dentry *old_dentry, struct inode *new_dir,
 		struct dentry *new_dentry, unsigned int flags)
