@@ -590,17 +590,17 @@ static u64 apfs_free_queue_oldest_xid(struct apfs_node *root)
  * apfs_flush_free_queue - Free ip blocks queued by old transactions
  * @sb:		superblock structure
  * @qid:	queue to be freed
- * @force:	flush as much as possible
  *
  * Returns 0 on success or a negative error code in case of failure.
  */
-static int apfs_flush_free_queue(struct super_block *sb, unsigned int qid, bool force)
+static int apfs_flush_free_queue(struct super_block *sb, unsigned int qid)
 {
 	struct apfs_nxsb_info *nxi = APFS_NXI(sb);
 	struct apfs_spaceman *sm = APFS_SM(sb);
 	struct apfs_spaceman_phys *sm_raw = sm->sm_raw;
 	struct apfs_spaceman_free_queue *fq = &sm_raw->sm_fq[qid];
 	struct apfs_node *fq_root;
+	struct apfs_btree_info *fq_info = NULL;
 	u64 oldest = le64_to_cpu(fq->sfq_oldest_xid);
 	int err;
 
@@ -612,19 +612,15 @@ static int apfs_flush_free_queue(struct super_block *sb, unsigned int qid, bool
 	}
 
 	while (oldest) {
-		u64 sfq_count;
-
 		/*
-		 * Try to preserve one transaction here. I don't really know
-		 * what free queues are for so this is probably silly.
+		 * Blocks freed in the current transaction can't be reused
+		 * safely until after the commit, but I don't think there is
+		 * any point in preserving old transacions. I'm guessing the
+		 * official driver keeps multiple transactions going at the
+		 * same time, that must be why they need a free queue.
 		 */
-		if (force) {
-			if (oldest == nxi->nx_xid)
-				break;
-		} else {
-			if (oldest + 1 >= nxi->nx_xid)
-				break;
-		}
+		if (oldest == nxi->nx_xid)
+			break;
 
 		while (true) {
 			u64 count = 0;
@@ -643,22 +639,16 @@ static int apfs_flush_free_queue(struct super_block *sb, unsigned int qid, bool
 		}
 		oldest = apfs_free_queue_oldest_xid(fq_root);
 		fq->sfq_oldest_xid = cpu_to_le64(oldest);
+	}
 
-		if (force)
-			continue;
-
-		/*
-		 * Flushing a single transaction may not be enough to avoid
-		 * running out of space in the ip, but it's probably best not
-		 * to flush all the old transactions at once either. We use a
-		 * harsher version of the apfs_transaction_need_commit() check,
-		 * to make sure we won't be forced to commit again right away.
-		 */
-		sfq_count = le64_to_cpu(fq->sfq_count);
-		if (qid == APFS_SFQ_IP && sfq_count * 6 <= le64_to_cpu(sm_raw->sm_ip_block_count))
-			break;
-		if (qid == APFS_SFQ_MAIN && sfq_count <= APFS_TRANS_MAIN_QUEUE_MAX - 200)
-			break;
+	if (qid == APFS_SFQ_MAIN) {
+		fq_info = (void *)fq_root->object.data + sb->s_blocksize - sizeof(*fq_info);
+		sm->sm_main_fq_nodes = le64_to_cpu(fq_info->bt_node_count);
+		if (sm->sm_main_fq_nodes != 1) {
+			apfs_alert(sb, "main queue wasn't flushed in full - bug!");
+			err = -EFSCORRUPTED;
+			goto fail;
+		}
 	}
 
 fail:
@@ -787,12 +777,16 @@ int apfs_read_spaceman(struct super_block *sb)
 		goto fail;
 	}
 
-	err = apfs_flush_free_queue(sb, APFS_SFQ_IP, false /* force */);
+	/*
+	 * We flush free queues whole when each transaction begins, to make it
+	 * harder for the btrees to become too unbalanced.
+	 */
+	err = apfs_flush_free_queue(sb, APFS_SFQ_IP);
 	if (err) {
 		apfs_err(sb, "failed to flush ip fq");
 		goto fail;
 	}
-	err = apfs_flush_free_queue(sb, APFS_SFQ_MAIN, false /* force */);
+	err = apfs_flush_free_queue(sb, APFS_SFQ_MAIN);
 	if (err) {
 		apfs_err(sb, "failed to flush main fq");
 		goto fail;
@@ -926,8 +920,7 @@ static inline int apfs_chunk_mark_free(struct super_block *sb, char *bitmap,
  * @count:	number of consecutive blocks to free
  *
  * Same as apfs_free_queue_insert_nocache(), except that this one can also fail
- * with -EAGAIN if there is no room for the new record, so that the caller can
- * flush the queue and retry.
+ * with -ENOSPC if there is no room for the new record.
  */
 static int apfs_free_queue_try_insert(struct super_block *sb, u64 bno, u64 count)
 {
@@ -944,12 +937,11 @@ static int apfs_free_queue_try_insert(struct super_block *sb, u64 bno, u64 count
 	__le64 raw_val;
 	u64 node_count;
 	u16 node_limit;
+	unsigned int qid;
 	int err;
 
-	if (apfs_block_in_ip(sm, bno))
-		fq = &sm_raw->sm_fq[APFS_SFQ_IP];
-	else
-		fq = &sm_raw->sm_fq[APFS_SFQ_MAIN];
+	qid = apfs_block_in_ip(sm, bno) ? APFS_SFQ_IP : APFS_SFQ_MAIN;
+	fq = &sm_raw->sm_fq[qid];
 
 	fq_root = apfs_read_node(sb, le64_to_cpu(fq->sfq_tree_oid),
 				 APFS_OBJ_EPHEMERAL, true /* write */);
@@ -978,7 +970,7 @@ static int apfs_free_queue_try_insert(struct super_block *sb, u64 bno, u64 count
 	if (node_count == node_limit) {
 		needed_room = sizeof(raw_key) + (ghost ? 0 : sizeof(raw_val));
 		if (!apfs_node_has_room(query->node, needed_room, false /* replace */)) {
-			err = -EAGAIN;
+			err = -ENOSPC;
 			goto fail;
 		}
 	}
@@ -1001,6 +993,9 @@ static int apfs_free_queue_try_insert(struct super_block *sb, u64 bno, u64 count
 		fq->sfq_oldest_xid = cpu_to_le64(nxi->nx_xid);
 	le64_add_cpu(&fq->sfq_count, count);
 
+	if (qid == APFS_SFQ_MAIN)
+		sm->sm_main_fq_nodes = le64_to_cpu(fq_info->bt_node_count);
+
 fail:
 	apfs_free_query(query);
 	apfs_node_free(fq_root);
@@ -1020,25 +1015,16 @@ fail:
  */
 int apfs_free_queue_insert_nocache(struct super_block *sb, u64 bno, u64 count)
 {
-	struct apfs_spaceman *sm = APFS_SM(sb);
 	unsigned int qid;
 	int err;
 
 	err = apfs_free_queue_try_insert(sb, bno, count);
-	if (err == -EAGAIN) {
-		qid = apfs_block_in_ip(sm, bno) ? APFS_SFQ_IP : APFS_SFQ_MAIN;
-		err = apfs_flush_free_queue(sb, qid, true /* force */);
-		if (err) {
-			apfs_err(sb, "failed to flush fq to make room");
-			return err;
-		}
-		err = apfs_free_queue_try_insert(sb, bno, count);
+	if (err == -ENOSPC) {
+		qid = apfs_block_in_ip(APFS_SM(sb), bno) ? APFS_SFQ_IP : APFS_SFQ_MAIN;
+		apfs_alert(sb, "free queue (%u) seems full - bug!", qid);
+		err = -EFSCORRUPTED;
 	}
 	if (err) {
-		if (err == -EAGAIN) {
-			apfs_alert(sb, "failed to make room in fq - bug!");
-			err = -EFSCORRUPTED;
-		}
 		apfs_err(sb, "fq insert failed (0x%llx-0x%llx)", bno, count);
 		return err;
 	}
@@ -1370,6 +1356,11 @@ int apfs_spaceman_allocate_block(struct super_block *sb, u64 *bno, bool backward
 			apfs_err(sb, "error during allocation");
 		return err;
 	}
+	/*
+	 * We checked the free space before starting the transaction, so this
+	 * isn't expected to happen.
+	 */
+	apfs_err(sb, "ran out of space during transaction");
 	return -ENOSPC;
 }
 
@@ -1396,10 +1387,11 @@ static int apfs_main_free(struct super_block *sb, u64 bno)
 {
 	struct apfs_spaceman *sm = APFS_SM(sb);
 	struct apfs_spaceman_phys *sm_raw = sm->sm_raw;
+	struct apfs_sb_info *sbi = NULL;
 	u64 cib_idx, chunk_idx;
 	struct buffer_head *cib_bh;
 	u64 cib_bno;
-	int err;
+	int err, orphan_err;
 
 	if (!sm_raw->sm_blocks_per_chunk || !sm_raw->sm_chunks_per_cib) {
 		apfs_err(sb, "block or chunk count not set");
@@ -1426,8 +1418,62 @@ static int apfs_main_free(struct super_block *sb, u64 bno)
 		apfs_write_spaceman(sm);
 	}
 	brelse(cib_bh);
-	if (err)
+	if (err) {
 		apfs_err(sb, "error during free");
+		return err;
+	}
+
+	/* It may be time to resume orphan cleanups, if we made enough room */
+	sbi = APFS_SB(sb);
+	orphan_err = atomic_read(&sbi->s_orphan_cleanup_err);
+	if (orphan_err == -ENOSPC && sm->sm_free_count >= 2 * APFS_DEL_ROOM) {
+		atomic_set(&sbi->s_orphan_cleanup_err, 0);
+		apfs_schedule_orphan_cleanup(sb);
+	}
 
 	return err;
 }
+
+/**
+ * apfs_spaceman_get_free_blkcnt - Calculate the total number of free blocks
+ * @sb:		filesystem superblock
+ * @blkcnt:	on return, the total number of free blocks for all devices
+ *
+ * Can be called even if the spaceman has not been read (for example, on a
+ * read-only mount). Returns 0 on success, or a negative error code in case of
+ * failure.
+ */
+int apfs_spaceman_get_free_blkcnt(struct super_block *sb, u64 *blkcnt)
+{
+	struct apfs_nxsb_info *nxi = APFS_NXI(sb);
+	struct apfs_nx_superblock *raw_sb = NULL;
+	struct apfs_spaceman_phys *sm_raw = NULL;
+	struct apfs_ephemeral_object_info *sm_eph_info = NULL;
+	struct apfs_spaceman_device *dev = NULL;
+	u64 oid;
+	int err;
+
+	if (!nxi->nx_eph_list) {
+		err = apfs_read_ephemeral_objects(sb);
+		if (err) {
+			apfs_err(sb, "failed to read the ephemeral objects");
+			return err;
+		}
+	}
+
+	raw_sb = nxi->nx_raw;
+	oid = le64_to_cpu(raw_sb->nx_spaceman_oid);
+	sm_eph_info = apfs_ephemeral_object_lookup(sb, oid);
+	if (IS_ERR(sm_eph_info)) {
+		apfs_err(sb, "no spaceman object for oid 0x%llx", oid);
+		return PTR_ERR(sm_eph_info);
+	}
+	sm_raw = (struct apfs_spaceman_phys *)sm_eph_info->object;
+
+	*blkcnt = 0;
+	dev = &sm_raw->sm_dev[APFS_SD_MAIN];
+	*blkcnt += le64_to_cpu(dev->sm_free_count);
+	dev = &sm_raw->sm_dev[APFS_SD_TIER2];
+	*blkcnt += le64_to_cpu(dev->sm_free_count);
+	return 0;
+}
